@@ -20,8 +20,8 @@
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  */
-#ifndef __parse_h
-#define __parse_h
+#ifndef __LXC_PARSE_H
+#define __LXC_PARSE_H
 
 typedef int (*lxc_dir_cb)(const char *name, const char *directory,
 			  const char *file, void *data);
